@@ -9,9 +9,13 @@ import sys
 import warnings
 
 import click
+from cligj import (
+    precision_opt, indent_opt, compact_opt, projection_geographic_opt,
+    projection_projected_opt, projection_mercator_opt,
+    sequence_opt, use_rs_opt, geojson_type_collection_opt,
+    geojson_type_feature_opt, geojson_type_bbox_opt)
 
 import rasterio
-
 from rasterio.rio.cli import cli, write_features
 
 
@@ -27,7 +31,11 @@ warnings.simplefilter('default')
 # Insp command.
 @cli.command(short_help="Open a data file and start an interpreter.")
 @click.argument('input', type=click.Path(exists=True))
-@click.option('--mode', type=click.Choice(['r', 'r+']), default='r', help="File mode (default 'r').")
+@click.option(
+    '--mode',
+    type=click.Choice(['r', 'r+']),
+    default='r',
+    help="File mode (default 'r').")
 @click.pass_context
 def insp(ctx, input, mode):
     import rasterio.tool
@@ -54,44 +62,20 @@ def insp(ctx, input, mode):
 # One or more files, the bounds of each are a feature in the collection
 # object or feature sequence.
 @click.argument('input', nargs=-1, type=click.Path(exists=True))
-# Coordinate precision option.
-@click.option('--precision', type=int, default=-1,
-              help="Decimal precision of coordinates.")
-# JSON formatting options.
-@click.option('--indent', default=None, type=int,
-              help="Indentation level for JSON output")
-@click.option('--compact/--no-compact', default=False,
-              help="Use compact separators (',', ':').")
-# Geographic (default) or Mercator switch.
-@click.option('--geographic', 'projected', flag_value='geographic',
-              default=True,
-              help="Output in geographic coordinates (the default).")
-@click.option('--projected', 'projected', flag_value='projected',
-              help="Output in projected coordinates.")
-@click.option('--mercator', 'projected', flag_value='mercator',
-              help="Output in Web Mercator coordinates.")
-# JSON object (default) or sequence (experimental) switch.
-@click.option('--json-obj', 'json_mode', flag_value='obj', default=True,
-        help="Write a single JSON object (the default).")
-@click.option('--x-json-seq', 'json_mode', flag_value='seq',
-        help="Write a JSON sequence. Experimental.")
-# Use ASCII RS control code to signal a sequence item (False is default).
-# See http://tools.ietf.org/html/draft-ietf-json-text-sequence-05.
-# Experimental.
-@click.option('--x-json-seq-rs/--x-json-seq-no-rs', default=False,
-        help="Use RS as text separator. Experimental.")
-# GeoJSON feature (default), bbox, or collection switch. Meaningful only
-# when --x-json-seq is used.
-@click.option('--collection', 'output_mode', flag_value='collection',
-              default=True,
-              help="Output as a GeoJSON feature collection (the default).")
-@click.option('--feature', 'output_mode', flag_value='feature',
-              help="Output as sequence of GeoJSON features.")
-@click.option('--bbox', 'output_mode', flag_value='bbox',
-              help="Output as a GeoJSON bounding box array.")
+@precision_opt
+@indent_opt
+@compact_opt
+@projection_geographic_opt
+@projection_projected_opt
+@projection_mercator_opt
+@sequence_opt
+@use_rs_opt
+@geojson_type_collection_opt(True)
+@geojson_type_feature_opt(False)
+@geojson_type_bbox_opt(False)
 @click.pass_context
-def bounds(ctx, input, precision, indent, compact, projected, json_mode,
-        x_json_seq_rs, output_mode):
+def bounds(ctx, input, precision, indent, compact, projection, sequence,
+        use_rs, geojson_type):
     """Write bounding boxes to stdout as GeoJSON for use with, e.g.,
     geojsonio
 
@@ -125,10 +109,10 @@ def bounds(ctx, input, precision, indent, compact, projected, json_mode,
                     bounds = src.bounds
                     xs = [bounds[0], bounds[2]]
                     ys = [bounds[1], bounds[3]]
-                    if projected == 'geographic':
+                    if projection == 'geographic':
                         xs, ys = rasterio.warp.transform(
                             src.crs, {'init': 'epsg:4326'}, xs, ys)
-                    if projected == 'mercator':
+                    if projection == 'mercator':
                         xs, ys = rasterio.warp.transform(
                             src.crs, {'init': 'epsg:3857'}, xs, ys)
                 if precision >= 0:
@@ -153,15 +137,14 @@ def bounds(ctx, input, precision, indent, compact, projected, json_mode,
                 self._xs.extend(bbox[::2])
                 self._ys.extend(bbox[1::2])
 
-    collection = Collection()
-
+    col = Collection()
     # Use the generator defined above as input to the generic output
     # writing function.
     try:
         with rasterio.drivers(CPL_DEBUG=verbosity>2):
             write_features(
-                stdout, collection, agg_mode=json_mode,
-                expression=output_mode, use_rs=x_json_seq_rs,
+                stdout, col, sequence=sequence,
+                geojson_type=geojson_type, use_rs=use_rs,
                 **dump_kwds)
         sys.exit(0)
     except Exception:
@@ -174,8 +157,7 @@ def bounds(ctx, input, precision, indent, compact, projected, json_mode,
 @click.argument('input', default='-', required=False)
 @click.option('--src_crs', default='EPSG:4326', help="Source CRS.")
 @click.option('--dst_crs', default='EPSG:4326', help="Destination CRS.")
-@click.option('--precision', type=int, default=-1,
-              help="Decimal precision of coordinates.")
+@precision_opt
 @click.pass_context
 def transform(ctx, input, src_crs, dst_crs, precision):
     import rasterio.warp
