@@ -90,19 +90,6 @@ class ReaderContextTest(unittest.TestCase):
             except:
                 assert "failed to catch exception" is False
 
-    def test_read_out_shape_resample(self):
-        with rasterio.open('tests/data/RGB.byte.tif') as s:
-            a = numpy.zeros((7, 8), dtype=rasterio.ubyte)
-            s.read_band(1, a)
-            self.assert_(
-                repr(a) == """array([[  0,   8,   5,   7,   0,   0,   0,   0],
-       [  0,   6,  61,  15,  27,  15,  24, 128],
-       [  0,  20, 152,  23,  15,  19,  28,   0],
-       [  0,  17, 255,  25, 255,  22,  32,   0],
-       [  9,   7,  14,  16,  19,  18,  36,   0],
-       [  6,  27,  43, 207,  38,  31,  73,   0],
-       [  0,   0,   0,   0,  74,  23,   0,   0]], dtype=uint8)""", a)
-
     def test_read_basic(self):
         with rasterio.open('tests/data/shade.tif') as s:
             a = s.read()  # Gray
